==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/OpenStackPlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenStackPlatformSpecBuilder extends io.fabric8.openshift.api.model.OpenStackPlatformSpecFluentImpl<io.fabric8.openshift.api.model.OpenStackPlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OpenStackPlatformSpec,io.fabric8.openshift.api.model.OpenStackPlatformSpecBuilder>{
  public OpenStackPlatformSpecBuilder() {
    this(false);
  }
  public OpenStackPlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenStackPlatformSpec(), validationEnabled);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenStackPlatformSpec(), validationEnabled);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.OpenStackPlatformSpec instance) {
    this(fluent, instance, false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.OpenStackPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpec instance) {
    this(instance,false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OpenStackPlatformSpec build() {
    OpenStackPlatformSpec buildable = new OpenStackPlatformSpec();
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenStackPlatformSpecBuilder that = (OpenStackPlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/OpenStackPlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenStackPlatformSpecBuilder extends io.fabric8.openshift.api.model.OpenStackPlatformSpecFluentImpl<io.fabric8.openshift.api.model.OpenStackPlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OpenStackPlatformSpec,io.fabric8.openshift.api.model.OpenStackPlatformSpecBuilder>{
  public OpenStackPlatformSpecBuilder() {
    this(false);
  }
  public OpenStackPlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenStackPlatformSpec(), validationEnabled);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenStackPlatformSpec(), validationEnabled);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.OpenStackPlatformSpec instance) {
    this(fluent, instance, false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.OpenStackPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpec instance) {
    this(instance,false);
  }
  public OpenStackPlatformSpecBuilder(io.fabric8.openshift.api.model.OpenStackPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OpenStackPlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OpenStackPlatformSpec build() {
    OpenStackPlatformSpec buildable = new OpenStackPlatformSpec();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenStackPlatformSpecBuilder that = (OpenStackPlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
